function create_wavetable()

    -- generuj nějakou náhodnost
    math.randomseed(os.clock())

    -- aktuální nástroj
    local instrument = renoise.song().selected_instrument
    
    -- počet samplů v nástroji
    local nr_samples = table.getn(instrument.samples)

    -- jestliže nástroj neobsahuje nejméně 2 samply tak se vrať
    if nr_samples ~= 2 then
        renoise.app():show_error("ERROR:\nYou need 2 samples in Instrument !!!")
        return
    end

    -- zjisti jestli oba buffery obsahují nějaká data
    if instrument.samples[1].sample_buffer.has_sample_data == false or instrument.samples[2].sample_buffer.has_sample_data == false then
        renoise.app():show_error("ERROR:\nIn both sample buffers must be some data !!!")
        return
    end

    -- teď jsou podporovány jen mono samply
    if instrument.samples[1].sample_buffer.number_of_channels ~= 1 or instrument.samples[2].sample_buffer.number_of_channels ~= 1 then
        renoise.app():show_error("ERROR:\nOnly Mono for now.")
        return
    end

    -- porovnej oba buffery
    -- protože délka druhého samplu se bude odvíjet od délky prvního samplu,
    -- tak nikdy nesmí být menší než délka prvního
    local len1 = instrument.samples[1].sample_buffer.number_of_frames
    local len2 = instrument.samples[2].sample_buffer.number_of_frames
    if len2 < len1 then
        renoise.app():show_error("Sample length mismatch !!!\n"..tostring(len1).." vs "..tostring(len2).."\n".."OriginalTo must be\nsame length or bigger.")
        return
    end

    -- nastav buffery odkud a kam a změn jména původních samplů
    -- které umístím na konec všech samplů
    local sample_from = instrument.samples[1].sample_buffer
    instrument.samples[1].name = "Original From"
    local sample_to = instrument.samples[2].sample_buffer
    instrument.samples[2].name = "Original To"

    -- informace o samplu které budu potřebovat
    local sample_rate = sample_from.sample_rate
    local number_of_channels = sample_from.number_of_channels
    local number_of_frames = sample_from.number_of_frames
    local bit_depth = sample_from.bit_depth

    -- načti morfované samply do pole
    local tempf = {}
    local tempt = {}
    for i=1, sample_from.number_of_frames do
        tempf[i] = sample_from:sample_data(1, i)
        tempt[i] = sample_to:sample_data(1, i)
    end
    
    local sample = {}
    local step = 0
    local offset = 1 / vbs["nr_samples"].value

    local morph = vbs["morph"].value
    local morph_fn = EaseIn
    if morph == 2 then
        morph_fn = EaseOut
    elseif morph == 3 then
        morph_fn = Spike
    end


    for index=1, Int(vbs["nr_samples"].value) do
        -- vytvoří nový sampl
        sample[index] = instrument:insert_sample_at(index)
        
        -- nastaví loop mod
        local sample_loop = vbs["loop"].value
        if sample_loop == 5 then
            sample_loop = math.random(1, 4)
        end
        sample[index].loop_mode = sample_loop
        
        -- nastaví aktuální sample buffer
        local buffer = sample[index].sample_buffer
        
        -- vytvoří nový prázdný sampl
        buffer:create_sample_data(sample_rate, bit_depth, number_of_channels, number_of_frames)
        
        -- zápis dat do aktuálního bufferu
        buffer:prepare_sample_data_changes()
        for j=1, number_of_frames do
            local result = precise_lerp(tempf[j], tempt[j], morph_fn(step, vbs["time"].value))
            buffer:set_sample_data(1, j, result)
        end
        buffer:finalize_sample_data_changes()

        -- přidej krok
        step = step + offset
    end

    -- nastaví mapování nástroje
    local o = vbs["overlay"].value
    if o == 1 then
        instrument.sample_mapping_overlap_mode = renoise.Instrument.OVERLAP_MODE_ALL
    elseif o == 2 then
        instrument.sample_mapping_overlap_mode = renoise.Instrument.OVERLAP_MODE_CYCLED
    elseif o == 3 then
        instrument.sample_mapping_overlap_mode = renoise.Instrument.OVERLAP_MODE_RANDOM
    end
end